@@ -47,7 +47,8 @@ from pygame_menu.utils import assert_list_vector, assert_color, make_surface, \
     is_callable, assert_vector, uuid4, warn
 
 from pygame_menu._types import List, Tuple2NumberType, ColorInputType, Tuple, \
-    Any, Dict, Union, NumberType, Tuple2IntType, Optional, Callable, NumberInstance
+    Any, Dict, Union, NumberType, Tuple2IntType, Optional, Callable, NumberInstance, \
+    CallableNoArgsType
 
 # Decoration constants
 DECORATION_ARC = 2000
@@ -658,7 +659,7 @@ class Decorator(Base):
 
     def add_callable(
             self,
-            fun: Union[Callable[['pygame.Surface', Any], Any], Callable[[], Any]],
+            fun: Union[Callable[['pygame.Surface', Any], Any], CallableNoArgsType],
             prev: bool = True,
             pass_args: bool = True
     ) -> str:
@@ -860,6 +861,18 @@ class Decorator(Base):
         self.force_cache_update(prev=decorid in self._decor_prev_id)
         return self
 
+    def is_enabled(self, decorid: str) -> bool:
+        """
+        Checks if a certain decoration is enabled or not. Raises ``IndexError``
+        if decoration was not found.
+
+        :param decorid: Decoration ID
+        :return: ``True`` if enabled
+        """
+        if decorid not in self._decor_enabled.keys():
+            raise IndexError('decoration<"{0}"> was not found'.format(decorid))
+        return self._decor_enabled[decorid]
+
     def remove(self, decorid: str) -> 'Decorator':
         """
         Remove a decoration from a given ID. Raises ``IndexError`` if decoration
