@@ -43,6 +43,7 @@ __all__ = [
     'check_key_pressed_valid',
     'fill_gradient',
     'format_color',
+    'get_cursor',
     'get_finger_pos',
     'is_callable',
     'load_pygame_image_file',
@@ -352,6 +353,19 @@ def format_color(
     return c.r, c.g, c.b, c.a
 
 
+def get_cursor() -> CursorInputType:
+    """
+    Returns the pygame cursor object.
+
+    :return: Cursor object
+    """
+    try:
+        return pygame.mouse.get_cursor()
+    except TypeError as e:
+        warn(str(e))
+    return None
+
+
 def get_finger_pos(menu: 'pygame_menu.Menu', event: EventType) -> Tuple2IntType:
     """
     Return the position from finger (or mouse) event on x-axis and y-axis (x, y).
@@ -412,13 +426,14 @@ def load_pygame_image_file(image_path: str, **kwargs) -> 'pygame.Surface':
                     img_pil.tobytes(), img_pil.size, img_pil.mode).convert()
 
             except (ModuleNotFoundError, ImportError):
-                warn('Image file could not be loaded, as pygame.error is'
-                     ' raised. To avoid this issue install the Pillow '
-                     'library')
+                warn('Image file "{0}" could not be loaded, as pygame.error is '
+                     'raised. To avoid this issue install the Pillow library'
+                     ''.format(image_path))
                 raise
 
             except pil_invalid_exception:
-                warn('The image could not be loaded using Pillow')
+                warn('The image "{0}" could not be loaded using Pillow'
+                     ''.format(image_path))
                 raise
 
         else:
