@@ -51,8 +51,8 @@ __all__ = [
 
 import pygame
 import pygame.gfxdraw as gfxdraw
+import pygame_menu.controls as ctrl
 
-from pygame_menu.controls import JOY_BUTTON_BACK
 from pygame_menu.locals import FINGERUP, POSITION_EAST, POSITION_WEST, POSITION_NORTH, \
     POSITION_SOUTH
 from pygame_menu.utils import assert_color, get_finger_pos, warn
@@ -188,6 +188,9 @@ class MenuBar(Widget):
     def resize(self, *args, **kwargs) -> 'MenuBar':
         return self
 
+    def rotate(self, *args, **kwargs) -> 'MenuBar':
+        return self
+
     def set_max_height(self, *args, **kwargs) -> 'MenuBar':
         return self
 
@@ -200,6 +203,9 @@ class MenuBar(Widget):
     def set_border(self, *args, **kwargs) -> 'MenuBar':
         return self
 
+    def flip(self, *args, **kwargs) -> 'MenuBar':
+        return self
+
     def _check_title_color(self, background_menu: bool) -> None:
         """
         Performs title color and prints a warning if the color is similar to the
@@ -564,7 +570,7 @@ class MenuBar(Widget):
 
             # User applies joy back button
             elif event.type == pygame.JOYBUTTONDOWN and self._joystick_enabled:
-                if event.button == JOY_BUTTON_BACK:
+                if event.button == ctrl.JOY_BUTTON_BACK:
                     self._sound.play_key_del()
                     self.apply()
                     updated = True
